@@ -13,6 +13,7 @@ class FilernameCdAdmin(BaseAdmin):
     """
     Custom admin for the FilernameCd model.
     """
+
     list_display = (
         "id",
         "xref_filer_id",
@@ -31,10 +32,8 @@ class FilerFilingsCdAdmin(BaseAdmin):
     """
     Custom admin for the FilerFilingsCd model.
     """
-    list_display = (
-        "id", "filer_id", "form_id",
-        "filing_id", "filing_sequence"
-    )
+
+    list_display = ("id", "filer_id", "form_id", "filing_id", "filing_sequence")
 
 
 @admin.register(models.FilingsCd)
@@ -42,6 +41,7 @@ class FilingsCdAdmin(BaseAdmin):
     """
     Custom admin for the FilingsCd model.
     """
+
     list_display = ("filing_id", "filing_type")
 
 
@@ -50,14 +50,15 @@ class SmryCdAdmin(BaseAdmin):
     """
     Custom admin for the SmryCd model.
     """
+
     list_display = (
-        'filing_id',
-        'amend_id',
-        'form_type',
-        'line_item',
-        'amount_a',
-        'amount_b',
-        'amount_c',
+        "filing_id",
+        "amend_id",
+        "form_type",
+        "line_item",
+        "amount_a",
+        "amount_b",
+        "amount_c",
     )
 
 
@@ -66,6 +67,7 @@ class SpltCdAdmin(BaseAdmin):
     """
     Custom admin for the SpltCd model.
     """
+
     list_display = (
         "filing_id",
         "amend_id",
@@ -82,6 +84,7 @@ class TextMemoCdAdmin(BaseAdmin):
     """
     Custom admin for the TextMemoCd model.
     """
+
     list_display = ("filing_id", "amend_id", "form_type")
 
 
@@ -90,7 +93,15 @@ class CvrE530CdAdmin(BaseAdmin):
     """
     Custom admin for the CvrE530Cd model.
     """
-    list_display = ("filing_id", "filer_naml", "office_cd", "cand_naml", "pmnt_dt", "pmnt_amount")
+
+    list_display = (
+        "filing_id",
+        "filer_naml",
+        "office_cd",
+        "cand_naml",
+        "pmnt_dt",
+        "pmnt_amount",
+    )
     date_hierarchy = "pmnt_dt"
 
 
@@ -99,8 +110,9 @@ class AcronymsCdAdmin(BaseAdmin):
     """
     Custom admin for the AcronymsCd model.
     """
+
     list_display = ("acronym", "stands_for", "effect_dt", "a_desc")
-    date_hierarchy = 'effect_dt'
+    date_hierarchy = "effect_dt"
 
 
 @admin.register(models.AddressCd)
@@ -108,7 +120,13 @@ class AddressCdAdmin(BaseAdmin):
     """
     Custom admin for the AddressCd model.
     """
-    list_display = ("adrid", "city", "st", "zip4",)
+
+    list_display = (
+        "adrid",
+        "city",
+        "st",
+        "zip4",
+    )
 
 
 @admin.register(models.FilersCd)
@@ -116,6 +134,7 @@ class FilersCdAdmin(BaseAdmin):
     """
     Custom admin for the FilersCd model.
     """
+
     list_display = ("filer_id",)
 
 
@@ -124,6 +143,7 @@ class FilerAcronymsCdAdmin(BaseAdmin):
     """
     Custom admin for the FilerAcronymsCd model.
     """
+
     list_display = ("acronym", "filer_id")
 
 
@@ -132,12 +152,8 @@ class FilerAddressCdAdmin(BaseAdmin):
     """
     Custom admin for the FilerAddressCd model.
     """
-    list_display = (
-        "filer_id",
-        "adrid",
-        "effect_dt",
-        "add_type"
-    )
+
+    list_display = ("filer_id", "adrid", "effect_dt", "add_type")
 
 
 @admin.register(models.FilerEthicsClassCd)
@@ -145,7 +161,12 @@ class FilerEthicsClassCdAdmin(BaseAdmin):
     """
     Custom admin for the FilerEthicsClassCd model.
     """
-    list_display = ("filer_id", "session_id", "ethics_date",)
+
+    list_display = (
+        "filer_id",
+        "session_id",
+        "ethics_date",
+    )
     date_hierarchy = "ethics_date"
 
 
@@ -154,12 +175,8 @@ class FilerInterestsCdAdmin(BaseAdmin):
     """
     Custom admin for the FilerInterestsCd model.
     """
-    list_display = (
-        "filer_id",
-        "session_id",
-        "interest_cd",
-        "effect_date"
-    )
+
+    list_display = ("filer_id", "session_id", "interest_cd", "effect_date")
     date_hierarchy = "effect_date"
 
 
@@ -168,6 +185,7 @@ class FilerLinksCdAdmin(BaseAdmin):
     """
     Custom admin for the FilerLinksCd model.
     """
+
     list_display = (
         "filer_id_a",
         "filer_id_b",
@@ -183,6 +201,7 @@ class FilerStatusTypesCdAdmin(BaseAdmin):
     """
     Custom admin for the FilerStatusTypesCd model.
     """
+
     list_display = ("status_type", "status_desc")
 
 
@@ -191,6 +210,7 @@ class FilerToFilerTypeCdAdmin(BaseAdmin):
     """
     Custom admin for the FilerToFilerTypeCd model.
     """
+
     list_display = (
         "filer_id",
         "filer_type",
@@ -199,7 +219,7 @@ class FilerToFilerTypeCdAdmin(BaseAdmin):
         "session_id",
         "race",
         "district_cd",
-        "party_cd"
+        "party_cd",
     )
     date_hierarchy = "effect_dt"
 
@@ -209,6 +229,7 @@ class FilerTypesCdAdmin(BaseAdmin):
     """
     Custom admin for the FilerTypesCd model.
     """
+
     list_display = (
         "filer_type",
         "description",
@@ -223,6 +244,7 @@ class FilerXrefCdAdmin(BaseAdmin):
     """
     Custom admin for the FilerXrefCd model.
     """
+
     list_display = ("filer_id", "xref_id", "effect_dt", "migration_source")
     date_hierarchy = "effect_dt"
 
@@ -232,6 +254,7 @@ class FilingPeriodCdAdmin(BaseAdmin):
     """
     Custom admin for the FilingPeriodCd model.
     """
+
     list_display = ("period_id", "start_date", "end_date", "period_desc")
 
 
@@ -240,6 +263,7 @@ class GroupTypesCdAdmin(BaseAdmin):
     """
     Custom admin for the GroupTypesCd model.
     """
+
     list_display = ("grp_id", "grp_name", "grp_desc")
 
 
@@ -248,7 +272,12 @@ class HeaderCdAdmin(BaseAdmin):
     """
     Custom admin for the HeaderCd model.
     """
-    list_display = ("line_number", "form_id", "rec_type",)
+
+    list_display = (
+        "line_number",
+        "form_id",
+        "rec_type",
+    )
 
 
 @admin.register(models.HdrCd)
@@ -256,7 +285,14 @@ class HdrCdAdmin(BaseAdmin):
     """
     Custom admin for the HdrCd model.
     """
-    list_display = ("filing_id", "amend_id", "cal_ver", "soft_name", "soft_ver",)
+
+    list_display = (
+        "filing_id",
+        "amend_id",
+        "cal_ver",
+        "soft_name",
+        "soft_ver",
+    )
 
 
 @admin.register(models.ImageLinksCd)
@@ -264,6 +300,7 @@ class ImageLinksCdAdmin(BaseAdmin):
     """
     Custom admin for the ImageLinksCd model.
     """
+
     list_display = ("img_link_id", "img_link_type", "img_id", "img_type", "img_dt")
     date_hierarchy = "img_dt"
 
@@ -273,6 +310,7 @@ class LegislativeSessionsCdAdmin(BaseAdmin):
     """
     Custom admin for the LegislativeSessionsCd model.
     """
+
     list_display = ("session_id", "begin_date", "end_date")
     date_hierarchy = "begin_date"
 
@@ -282,6 +320,7 @@ class LookupCodesCdAdmin(BaseAdmin):
     """
     Custom admin for the LookupCodesCd model.
     """
+
     list_display = (
         "code_type",
         "code_id",
@@ -294,7 +333,12 @@ class NamesCdAdmin(BaseAdmin):
     """
     Custom admin for the NamesCd model.
     """
-    list_display = ("namid", "namf", "naml",)
+
+    list_display = (
+        "namid",
+        "namf",
+        "naml",
+    )
 
 
 @admin.register(models.ReceivedFilingsCd)
@@ -302,7 +346,13 @@ class ReceivedFilingsCdAdmin(BaseAdmin):
     """
     Custom admin for the ReceivedFilingsCd model.
     """
-    list_display = ("filing_id", "filer_id", "form_id", "received_date",)
+
+    list_display = (
+        "filing_id",
+        "filer_id",
+        "form_id",
+        "received_date",
+    )
     date_hierarchy = "received_date"
 
 
@@ -311,4 +361,5 @@ class ReportsCdAdmin(BaseAdmin):
     """
     Custom admin for the ReportsCd model.
     """
+
     list_display = ("rpt_name", "rpt_id", "rpt_type")
